@@ -27,7 +27,7 @@ final readonly class CoversMethod extends Metadata
     private string $methodName;
 
     /**
-     * @param 0|1              $level
+     * @param int<0, 1>        $level
      * @param class-string     $className
      * @param non-empty-string $methodName
      */
@@ -59,14 +59,4 @@ final readonly class CoversMethod extends Metadata
     {
         return $this->methodName;
     }
-
-    /**
-     * @return non-empty-string
-     *
-     * @internal This method is not covered by the backward compatibility promise for PHPUnit
-     */
-    public function asStringForCodeUnitMapper(): string
-    {
-        return $this->className . '::' . $this->methodName;
-    }
 }
