@@ -19,25 +19,19 @@ use PHPUnit\Runner\Extension\Extension;
  */
 abstract readonly class Metadata
 {
-    private const CLASS_LEVEL  = 0;
-    private const METHOD_LEVEL = 1;
+    private const int CLASS_LEVEL  = 0;
+    private const int METHOD_LEVEL = 1;
 
     /**
-     * @var 0|1
+     * @var int<0, 1>
      */
     private int $level;
 
-    /**
-     * @param non-negative-int $priority
-     */
     public static function after(int $priority): After
     {
         return new After(self::METHOD_LEVEL, $priority);
     }
 
-    /**
-     * @param non-negative-int $priority
-     */
     public static function afterClass(int $priority): AfterClass
     {
         return new AfterClass(self::METHOD_LEVEL, $priority);
@@ -63,22 +57,24 @@ abstract readonly class Metadata
         return new BackupStaticProperties(self::METHOD_LEVEL, $enabled);
     }
 
-    /**
-     * @param non-negative-int $priority
-     */
     public static function before(int $priority): Before
     {
         return new Before(self::METHOD_LEVEL, $priority);
     }
 
-    /**
-     * @param non-negative-int $priority
-     */
     public static function beforeClass(int $priority): BeforeClass
     {
         return new BeforeClass(self::METHOD_LEVEL, $priority);
     }
 
+    /**
+     * @param non-empty-string $namespace
+     */
+    public static function coversNamespace(string $namespace): CoversNamespace
+    {
+        return new CoversNamespace(self::CLASS_LEVEL, $namespace);
+    }
+
     /**
      * @param class-string $className
      */
@@ -87,6 +83,22 @@ abstract readonly class Metadata
         return new CoversClass(self::CLASS_LEVEL, $className);
     }
 
+    /**
+     * @param class-string $className
+     */
+    public static function coversClassesThatExtendClass(string $className): CoversClassesThatExtendClass
+    {
+        return new CoversClassesThatExtendClass(self::CLASS_LEVEL, $className);
+    }
+
+    /**
+     * @param class-string $interfaceName
+     */
+    public static function coversClassesThatImplementInterface(string $interfaceName): CoversClassesThatImplementInterface
+    {
+        return new CoversClassesThatImplementInterface(self::CLASS_LEVEL, $interfaceName);
+    }
+
     /**
      * @param trait-string $traitName
      */
@@ -112,30 +124,6 @@ abstract readonly class Metadata
         return new CoversFunction(self::CLASS_LEVEL, $functionName);
     }
 
-    /**
-     * @param non-empty-string $target
-     */
-    public static function coversOnClass(string $target): Covers
-    {
-        return new Covers(self::CLASS_LEVEL, $target);
-    }
-
-    /**
-     * @param non-empty-string $target
-     */
-    public static function coversOnMethod(string $target): Covers
-    {
-        return new Covers(self::METHOD_LEVEL, $target);
-    }
-
-    /**
-     * @param class-string $className
-     */
-    public static function coversDefaultClass(string $className): CoversDefaultClass
-    {
-        return new CoversDefaultClass(self::CLASS_LEVEL, $className);
-    }
-
     public static function coversNothingOnClass(): CoversNothing
     {
         return new CoversNothing(self::CLASS_LEVEL);
@@ -150,9 +138,9 @@ abstract readonly class Metadata
      * @param class-string     $className
      * @param non-empty-string $methodName
      */
-    public static function dataProvider(string $className, string $methodName): DataProvider
+    public static function dataProvider(string $className, string $methodName, bool $validateArgumentCount): DataProvider
     {
-        return new DataProvider(self::METHOD_LEVEL, $className, $methodName);
+        return new DataProvider(self::METHOD_LEVEL, $className, $methodName, $validateArgumentCount);
     }
 
     /**
@@ -237,14 +225,20 @@ abstract readonly class Metadata
         return new Group(self::METHOD_LEVEL, $groupName);
     }
 
-    public static function ignoreDeprecationsOnClass(): IgnoreDeprecations
+    /**
+     * @param null|non-empty-string $messagePattern
+     */
+    public static function ignoreDeprecationsOnClass(?string $messagePattern = null): IgnoreDeprecations
     {
-        return new IgnoreDeprecations(self::CLASS_LEVEL);
+        return new IgnoreDeprecations(self::CLASS_LEVEL, $messagePattern);
     }
 
-    public static function ignoreDeprecationsOnMethod(): IgnoreDeprecations
+    /**
+     * @param null|non-empty-string $messagePattern
+     */
+    public static function ignoreDeprecationsOnMethod(?string $messagePattern = null): IgnoreDeprecations
     {
-        return new IgnoreDeprecations(self::METHOD_LEVEL);
+        return new IgnoreDeprecations(self::METHOD_LEVEL, $messagePattern);
     }
 
     /**
@@ -263,17 +257,11 @@ abstract readonly class Metadata
         return new IgnorePhpunitDeprecations(self::METHOD_LEVEL);
     }
 
-    /**
-     * @param non-negative-int $priority
-     */
     public static function postCondition(int $priority): PostCondition
     {
         return new PostCondition(self::METHOD_LEVEL, $priority);
     }
 
-    /**
-     * @param non-negative-int $priority
-     */
     public static function preCondition(int $priority): PreCondition
     {
         return new PreCondition(self::METHOD_LEVEL, $priority);
@@ -407,6 +395,26 @@ abstract readonly class Metadata
         return new RequiresPhpunitExtension(self::METHOD_LEVEL, $extensionClass);
     }
 
+    public static function requiresEnvironmentVariableOnClass(string $environmentVariableName, null|string $value): RequiresEnvironmentVariable
+    {
+        return new RequiresEnvironmentVariable(self::CLASS_LEVEL, $environmentVariableName, $value);
+    }
+
+    public static function requiresEnvironmentVariableOnMethod(string $environmentVariableName, null|string $value): RequiresEnvironmentVariable
+    {
+        return new RequiresEnvironmentVariable(self::METHOD_LEVEL, $environmentVariableName, $value);
+    }
+
+    public static function withEnvironmentVariableOnClass(string $environmentVariableName, null|string $value): WithEnvironmentVariable
+    {
+        return new WithEnvironmentVariable(self::CLASS_LEVEL, $environmentVariableName, $value);
+    }
+
+    public static function withEnvironmentVariableOnMethod(string $environmentVariableName, null|string $value): WithEnvironmentVariable
+    {
+        return new WithEnvironmentVariable(self::METHOD_LEVEL, $environmentVariableName, $value);
+    }
+
     /**
      * @param non-empty-string $setting
      * @param non-empty-string $value
@@ -462,14 +470,30 @@ abstract readonly class Metadata
     }
 
     /**
-     * @param array<array<mixed>> $data
-     * @param ?non-empty-string   $name
+     * @param class-string     $className
+     * @param non-empty-string $methodName
      */
-    public static function testWith(array $data, ?string $name = null): TestWith
+    public static function testDoxFormatter(string $className, string $methodName): TestDoxFormatter
+    {
+        return new TestDoxFormatter(self::METHOD_LEVEL, $className, $methodName);
+    }
+
+    /**
+     * @param ?non-empty-string $name
+     */
+    public static function testWith(mixed $data, ?string $name = null): TestWith
     {
         return new TestWith(self::METHOD_LEVEL, $data, $name);
     }
 
+    /**
+     * @param non-empty-string $namespace
+     */
+    public static function usesNamespace(string $namespace): UsesNamespace
+    {
+        return new UsesNamespace(self::CLASS_LEVEL, $namespace);
+    }
+
     /**
      * @param class-string $className
      */
@@ -478,10 +502,26 @@ abstract readonly class Metadata
         return new UsesClass(self::CLASS_LEVEL, $className);
     }
 
+    /**
+     * @param class-string $className
+     */
+    public static function usesClassesThatExtendClass(string $className): UsesClassesThatExtendClass
+    {
+        return new UsesClassesThatExtendClass(self::CLASS_LEVEL, $className);
+    }
+
+    /**
+     * @param class-string $interfaceName
+     */
+    public static function usesClassesThatImplementInterface(string $interfaceName): UsesClassesThatImplementInterface
+    {
+        return new UsesClassesThatImplementInterface(self::CLASS_LEVEL, $interfaceName);
+    }
+
     /**
      * @param trait-string $traitName
      */
-    public static function UsesTrait(string $traitName): UsesTrait
+    public static function usesTrait(string $traitName): UsesTrait
     {
         return new UsesTrait(self::CLASS_LEVEL, $traitName);
     }
@@ -503,37 +543,21 @@ abstract readonly class Metadata
         return new UsesMethod(self::CLASS_LEVEL, $className, $methodName);
     }
 
-    /**
-     * @param non-empty-string $target
-     */
-    public static function usesOnClass(string $target): Uses
-    {
-        return new Uses(self::CLASS_LEVEL, $target);
-    }
-
-    /**
-     * @param non-empty-string $target
-     */
-    public static function usesOnMethod(string $target): Uses
-    {
-        return new Uses(self::METHOD_LEVEL, $target);
-    }
-
-    /**
-     * @param class-string $className
-     */
-    public static function usesDefaultClass(string $className): UsesDefaultClass
-    {
-        return new UsesDefaultClass(self::CLASS_LEVEL, $className);
-    }
-
     public static function withoutErrorHandler(): WithoutErrorHandler
     {
         return new WithoutErrorHandler(self::METHOD_LEVEL);
     }
 
     /**
-     * @param 0|1 $level
+     * @param null|non-empty-string $messagePattern
+     */
+    public static function ignorePhpunitWarnings(?string $messagePattern): IgnorePhpunitWarnings
+    {
+        return new IgnorePhpunitWarnings(self::METHOD_LEVEL, $messagePattern);
+    }
+
+    /**
+     * @param int<0, 1> $level
      */
     protected function __construct(int $level)
     {
@@ -599,9 +623,9 @@ abstract readonly class Metadata
     }
 
     /**
-     * @phpstan-assert-if-true Covers $this
+     * @phpstan-assert-if-true CoversNamespace $this
      */
-    public function isCovers(): bool
+    public function isCoversNamespace(): bool
     {
         return false;
     }
@@ -615,9 +639,17 @@ abstract readonly class Metadata
     }
 
     /**
-     * @phpstan-assert-if-true CoversDefaultClass $this
+     * @phpstan-assert-if-true CoversClassesThatExtendClass $this
      */
-    public function isCoversDefaultClass(): bool
+    public function isCoversClassesThatExtendClass(): bool
+    {
+        return false;
+    }
+
+    /**
+     * @phpstan-assert-if-true CoversClassesThatImplementInterface $this
+     */
+    public function isCoversClassesThatImplementInterface(): bool
     {
         return false;
     }
@@ -856,6 +888,22 @@ abstract readonly class Metadata
         return false;
     }
 
+    /**
+     * @phpstan-assert-if-true RequiresEnvironmentVariable $this
+     */
+    public function isRequiresEnvironmentVariable(): bool
+    {
+        return false;
+    }
+
+    /**
+     * @phpstan-assert-if-true WithEnvironmentVariable $this
+     */
+    public function isWithEnvironmentVariable(): bool
+    {
+        return false;
+    }
+
     /**
      * @phpstan-assert-if-true RequiresSetting $this
      */
@@ -872,6 +920,14 @@ abstract readonly class Metadata
         return false;
     }
 
+    /**
+     * @phpstan-assert-if-true TestDoxFormatter $this
+     */
+    public function isTestDoxFormatter(): bool
+    {
+        return false;
+    }
+
     /**
      * @phpstan-assert-if-true TestWith $this
      */
@@ -881,9 +937,9 @@ abstract readonly class Metadata
     }
 
     /**
-     * @phpstan-assert-if-true Uses $this
+     * @phpstan-assert-if-true UsesNamespace $this
      */
-    public function isUses(): bool
+    public function isUsesNamespace(): bool
     {
         return false;
     }
@@ -897,9 +953,17 @@ abstract readonly class Metadata
     }
 
     /**
-     * @phpstan-assert-if-true UsesDefaultClass $this
+     * @phpstan-assert-if-true UsesClassesThatExtendClass $this
      */
-    public function isUsesDefaultClass(): bool
+    public function isUsesClassesThatExtendClass(): bool
+    {
+        return false;
+    }
+
+    /**
+     * @phpstan-assert-if-true UsesClassesThatImplementInterface $this
+     */
+    public function isUsesClassesThatImplementInterface(): bool
     {
         return false;
     }
@@ -935,4 +999,12 @@ abstract readonly class Metadata
     {
         return false;
     }
+
+    /**
+     * @phpstan-assert-if-true IgnorePhpunitWarnings $this
+     */
+    public function isIgnorePhpunitWarnings(): bool
+    {
+        return false;
+    }
 }
