@@ -9,13 +9,12 @@
  */
 namespace PHPUnit\TestFixture;
 
+use PHPUnit\Framework\Attributes\DoesNotPerformAssertions;
 use PHPUnit\Framework\TestCase;
 
-class DoesNotPerformAssertionsButPerformingAssertionsTest extends TestCase
+final class DoesNotPerformAssertionsButPerformingAssertionsTest extends TestCase
 {
-    /**
-     * @doesNotPerformAssertions
-     */
+    #[DoesNotPerformAssertions]
     public function testFalseAndTrueAreStillFine(): void
     {
         $this->assertFalse(false);
