@@ -10,20 +10,23 @@
 namespace PHPUnit\TestFixture\Metadata\Attribute;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\CoversClassesThatExtendClass;
+use PHPUnit\Framework\Attributes\CoversClassesThatImplementInterface;
 use PHPUnit\Framework\Attributes\CoversFunction;
 use PHPUnit\Framework\Attributes\CoversMethod;
-use PHPUnit\Framework\Attributes\CoversNothing;
+use PHPUnit\Framework\Attributes\CoversNamespace;
 use PHPUnit\Framework\Attributes\CoversTrait;
 use PHPUnit\Framework\TestCase;
 
+#[CoversNamespace('PHPUnit\TestFixture\Metadata\Attribute')]
 #[CoversClass(Example::class)]
+#[CoversClassesThatExtendClass(Example::class)]
+#[CoversClassesThatImplementInterface(Example::class)]
 #[CoversTrait(ExampleTrait::class)]
 #[CoversMethod(Example::class, 'method')]
 #[CoversFunction('f')]
-#[CoversNothing]
 final class CoversTest extends TestCase
 {
-    #[CoversNothing]
     public function testOne(): void
     {
     }
