@@ -10,15 +10,24 @@
 namespace PHPUnit\TestFixture\Metadata\Attribute;
 
 use PHPUnit\Framework\Attributes\UsesClass;
+use PHPUnit\Framework\Attributes\UsesClassesThatExtendClass;
+use PHPUnit\Framework\Attributes\UsesClassesThatImplementInterface;
 use PHPUnit\Framework\Attributes\UsesFunction;
 use PHPUnit\Framework\Attributes\UsesMethod;
+use PHPUnit\Framework\Attributes\UsesNamespace;
 use PHPUnit\Framework\Attributes\UsesTrait;
 use PHPUnit\Framework\TestCase;
 
+#[UsesNamespace('PHPUnit\TestFixture\Metadata\Attribute')]
 #[UsesClass(Example::class)]
+#[UsesClassesThatExtendClass(Example::class)]
+#[UsesClassesThatImplementInterface(Example::class)]
 #[UsesTrait(ExampleTrait::class)]
 #[UsesMethod(Example::class, 'method')]
 #[UsesFunction('f')]
 final class UsesTest extends TestCase
 {
+    public function testOne(): void
+    {
+    }
 }
