@@ -23,18 +23,11 @@ final class TestCaseTest extends TestCase
     {
     }
 
-    /**
-     * @test
-     */
     public function three(): void
     {
     }
 
-    public function four(): void
-    {
-    }
-
-    private function five(): void
+    private function four(): void
     {
     }
 }
