@@ -21,17 +21,18 @@ final class BeforeTestMethodCalledTest extends AbstractEventTestCase
     public function testConstructorSetsValues(): void
     {
         $telemetryInfo = $this->telemetryInfo();
-        $testClassName = 'Test';
+        $test          = $this->testValueObject();
         $calledMethod  = $this->calledMethod();
 
         $event = new BeforeTestMethodCalled(
             $telemetryInfo,
-            $testClassName,
+            $test,
             $calledMethod,
         );
 
         $this->assertSame($telemetryInfo, $event->telemetryInfo());
-        $this->assertSame($testClassName, $event->testClassName());
+        $this->assertSame($test, $event->test());
+        $this->assertSame('FooTest', $event->testClassName());
         $this->assertSame($calledMethod, $event->calledMethod());
     }
 
@@ -39,7 +40,7 @@ final class BeforeTestMethodCalledTest extends AbstractEventTestCase
     {
         $event = new BeforeTestMethodCalled(
             $this->telemetryInfo(),
-            'Test',
+            $this->testValueObject(),
             $this->calledMethod(),
         );
 
