@@ -44,7 +44,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -77,7 +76,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -110,7 +108,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -143,7 +140,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -176,7 +172,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -209,7 +204,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -227,68 +221,6 @@ final class SourceTest extends TestCase
         $source->baseline();
     }
 
-    public function testRestrictionOfDeprecationsMayBeDisabled(): void
-    {
-        $source = new Source(
-            null,
-            false,
-            FilterDirectoryCollection::fromArray([]),
-            FileCollection::fromArray([]),
-            FilterDirectoryCollection::fromArray([]),
-            FileCollection::fromArray([]),
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            [
-                'functions' => [],
-                'methods'   => [],
-            ],
-            false,
-            false,
-            false,
-        );
-
-        $this->assertFalse($source->restrictDeprecations());
-    }
-
-    public function testRestrictionOfDeprecationsMayBeEnabled(): void
-    {
-        $source = new Source(
-            null,
-            false,
-            FilterDirectoryCollection::fromArray([]),
-            FileCollection::fromArray([]),
-            FilterDirectoryCollection::fromArray([]),
-            FileCollection::fromArray([]),
-            true,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            false,
-            [
-                'functions' => [],
-                'methods'   => [],
-            ],
-            false,
-            false,
-            false,
-        );
-
-        $this->assertTrue($source->restrictDeprecations());
-    }
-
     public function testRestrictionOfNoticesMayBeDisabled(): void
     {
         $source = new Source(
@@ -307,7 +239,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -329,7 +260,6 @@ final class SourceTest extends TestCase
             FileCollection::fromArray([]),
             FilterDirectoryCollection::fromArray([]),
             FileCollection::fromArray([]),
-            false,
             true,
             false,
             false,
@@ -369,7 +299,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -392,7 +321,6 @@ final class SourceTest extends TestCase
             FilterDirectoryCollection::fromArray([]),
             FileCollection::fromArray([]),
             false,
-            false,
             true,
             false,
             false,
@@ -431,7 +359,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -455,7 +382,6 @@ final class SourceTest extends TestCase
             FileCollection::fromArray([]),
             false,
             false,
-            false,
             true,
             false,
             false,
@@ -493,7 +419,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -518,7 +443,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             true,
             false,
             false,
@@ -555,7 +479,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -581,7 +504,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             true,
             false,
             false,
@@ -617,7 +539,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -644,7 +565,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             true,
             false,
             false,
@@ -679,7 +599,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -707,7 +626,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             true,
             false,
             false,
@@ -741,7 +659,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -770,7 +687,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             true,
             false,
             [
@@ -803,7 +719,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -833,7 +748,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             true,
             [
                 'functions' => [],
@@ -865,7 +779,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
@@ -904,7 +817,6 @@ final class SourceTest extends TestCase
             false,
             false,
             false,
-            false,
             [
                 'functions' => [],
                 'methods'   => [],
